Python Triangle
===============

|Build Status| |Version Status| |Downloads|

*Python Triangle* is a python wrapper around Jonathan Richard Shewchuk's
two-dimensional quality mesh generator and delaunay triangulator library,
available `here <http://www.cs.cmu.edu/~quake/triangle.html>`_.

This implementation of python triangle utilizes cython to wrap the C API as
closely as possible.

See the documentation at http://dzhelil.info/triangle/

.. |Build Status| image:: https://travis-ci.org/drufat/triangle.png
   :target: https://travis-ci.org/drufat/triangle
.. |Version Status| image:: https://img.shields.io/pypi/v/triangle.svg
   :target: https://pypi.python.org/pypi/triangle/
.. |Downloads| image:: https://img.shields.io/pypi/dm/triangle.svg
   :target: https://pypi.python.org/pypi/triangle/
